[Bf-blender-cvs] [402a4cadba4] master: CMake/LLVM: Add INCLUDE_DIRS to find package.

Ankit Meel noreply at git.blender.org
Fri Sep 18 15:44:09 CEST 2020


Commit: 402a4cadba495a57a4ee789a2ed6c4b9acaecba9
Author: Ankit Meel
Date:   Thu Sep 17 16:59:35 2020 +0530
Branches: master
https://developer.blender.org/rB402a4cadba495a57a4ee789a2ed6c4b9acaecba9

CMake/LLVM: Add INCLUDE_DIRS to find package.

Ref {D8855}

Reviewed By: brecht

Differential Revision: https://developer.blender.org/D8919

===================================================================

M	build_files/cmake/Modules/FindLLVM.cmake

===================================================================

diff --git a/build_files/cmake/Modules/FindLLVM.cmake b/build_files/cmake/Modules/FindLLVM.cmake
index d7269a4281f..ce4297bf54a 100644
--- a/build_files/cmake/Modules/FindLLVM.cmake
+++ b/build_files/cmake/Modules/FindLLVM.cmake
@@ -34,6 +34,10 @@ else()
   endif()
 endif()
 
+execute_process(COMMAND ${LLVM_CONFIG} --includedir
+      OUTPUT_VARIABLE LLVM_INCLUDE_DIRS
+      OUTPUT_STRIP_TRAILING_WHITESPACE)
+
 if(NOT DEFINED LLVM_VERSION)
   execute_process(COMMAND ${LLVM_CONFIG} --version
           OUTPUT_VARIABLE LLVM_VERSION
@@ -80,7 +84,7 @@ if(LLVM_LIBRARY AND LLVM_ROOT_DIR AND LLVM_LIBPATH)
 endif()
 
 
 # handle the QUIETLY and REQUIRED arguments and set SDL2_FOUND to TRUE if
 # all listed variables are TRUE
 INCLUDE(FindPackageHandleStandardArgs)
 FIND_PACKAGE_HANDLE_STANDARD_ARGS(LLVM DEFAULT_MSG
@@ -80,7 +84,7 @@ if(LLVM_LIBRARY AND LLVM_ROOT_DIR AND LLVM_LIBPATH)
 
 
-# handle the QUIETLY and REQUIRED arguments and set SDL2_FOUND to TRUE if
+# handle the QUIETLY and REQUIRED arguments and set LLVM_FOUND to TRUE if
 # all listed variables are TRUE
 INCLUDE(FindPackageHandleStandardArgs)



More information about the Bf-blender-cvs mailing list